@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2025 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2025 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -45,11 +36,14 @@ import legacy
 
 import admin_scripts.extra as extra
 
-USAGE_MESSAGE = "jssource [-r] [-w exclusion_1, exclusion_2, ...] [-c configuration_file]"
+USAGE_MESSAGE = (
+    "jssource [-r] [-w exclusion_1, exclusion_2, ...] [-c configuration_file]"
+)
 """ The usage message to be printed in case there's an
 error with the command line or help is requested. """
 
-def jssource_file(file_path, beautifty = True, encoding = "utf-8"):
+
+def jssource_file(file_path, beautify=True, encoding="utf-8"):
     """
     Runs the javascript source file verification/validation process
     as defined by a series of specifications.
@@ -57,26 +51,30 @@ def jssource_file(file_path, beautifty = True, encoding = "utf-8"):
     :type file_path: String
     :param file_path: The path to the file that is going to be
     changed according to the jssource operation.
-    :type beautifier: bool
-    :param beautifier: If the beautification process should be
+    :type beautify: bool
+    :param beautify: If the beautification process should be
     run for the provided file for verification.
     :type encoding: String
     :param encoding: The encoding that is going to be used as the
     default one for the decoding operation in the source file.
     """
 
-    try: import jsbeautifier
-    except: jsbeautifier = None
+    try:
+        import jsbeautifier
+    except ImportError:
+        jsbeautifier = None
 
     is_min = file_path.endswith("min.js")
 
-    if jsbeautifier and beautifty and not is_min:
+    if jsbeautifier and beautify and not is_min:
         # reads the complete set of contents from the original
         # file and then tries to decode such contents using the
         # default encoding (as expected by the processor)
         file = open(file_path, "rb")
-        try: contents = file.read()
-        finally: file.close()
+        try:
+            contents = file.read()
+        finally:
+            file.close()
         contents = contents.decode(encoding)
 
         # creates the dictionary that will contain the complete
@@ -88,16 +86,20 @@ def jssource_file(file_path, beautifty = True, encoding = "utf-8"):
         opts.preserve_newlines = True
         opts.operator_position = "after_newline"
         opts.eol = "\r\n"
-        result = jsbeautifier.beautify(contents, opts = opts)
+        result = jsbeautifier.beautify(contents, opts=opts)
 
         # determines if the result from the beautification process
         # is a bytes or unicode value and if it's not runs the encoding
         # and the re-writes the file with the new contents
         is_unicode = legacy.is_unicode(result)
-        if is_unicode: result = result.encode(encoding)
+        if is_unicode:
+            result = result.encode(encoding)
         file = open(file_path, "wb")
-        try: file.write(result)
-        finally: file.close()
+        try:
+            file.write(result)
+        finally:
+            file.close()
+
 
 def jssource_walker(arguments, directory_name, names):
     """
@@ -113,27 +115,35 @@ def jssource_walker(arguments, directory_name, names):
     """
 
     # unpacks the arguments tuple
-    file_exclusion, = arguments
+    (file_exclusion,) = arguments
 
     # tries to run the handle ignore operation for the current set of names and
     # in case there's a processing returns the control flow immediately as no
     # more handling is meant to occur for the current operation (ignored)
-    if extra.handle_ignore(names): return
+    if extra.handle_ignore(names):
+        return
 
     # removes the complete set of names that are meant to be excluded from the
     # current set names to be visit (avoid visiting them)
     for exclusion in file_exclusion:
-        if not exclusion in names: continue
+        if not exclusion in names:
+            continue
         names.remove(exclusion)
 
     # retrieves the valid names for the names list (removes directory entries)
-    valid_complete_names = [directory_name + "/" + name for name in names\
-        if not os.path.isdir(directory_name + "/" + name)]
+    valid_complete_names = [
+        directory_name + "/" + name
+        for name in names
+        if not os.path.isdir(directory_name + "/" + name)
+    ]
 
     # filters the names with non valid file extensions so that only the
     # ones that conform with the javascript source ones are selected
-    valid_complete_names = [os.path.normpath(name) for name in valid_complete_names\
-        if name.endswith((".js", ".json"))]
+    valid_complete_names = [
+        os.path.normpath(name)
+        for name in valid_complete_names
+        if name.endswith((".js", ".json"))
+    ]
 
     # iterates over all the valid complete names with valid structure
     # as defined by the javascript file structure definition
@@ -141,9 +151,10 @@ def jssource_walker(arguments, directory_name, names):
         # print a message a message about the jssource
         # operation that is going to be performed and
         # then runs the operation with the correct path
-        extra.echo("Transforming javascript source file: %s" % valid_complete_name)
+        extra.echo("Transforming javascript source file (beautify): %s" % valid_complete_name)
         jssource_file(valid_complete_name)
 
+
 def jssource_recursive(directory_path, file_exclusion):
     """
     Normalizes jssource in recursive mode.
@@ -160,9 +171,10 @@ def jssource_recursive(directory_path, file_exclusion):
     extra.shell_exec(
         "jshint",
         [directory_path, "--config", _config("jshint.json")],
-        tester = ["jshint", "--version"]
+        tester=["jshint", "--version"],
     )
 
+
 def _config(name):
     base_path = os.path.dirname(__file__)
     base_path = os.path.abspath(base_path)
@@ -172,6 +184,7 @@ def _config(name):
     name_path = os.path.normpath(name_path)
     return name_path
 
+
 def main():
     """
     Main function used for the jssource file normalization.
@@ -218,9 +231,9 @@ def main():
     # retrieves the configurations from the command line arguments
     # either from the command line or configuration file
     configurations = extra.configuration(
-        file_path = configuration_file_path,
-        recursive = recursive,
-        file_exclusion = file_exclusion
+        file_path=configuration_file_path,
+        recursive=recursive,
+        file_exclusion=file_exclusion,
     )
 
     # iterates over all the configurations, executing them
@@ -231,15 +244,18 @@ def main():
 
         # in case the recursive flag is set, normalizes the multiple
         # found jssource configuration file
-        if recursive: jssource_recursive(path, file_exclusion)
+        if recursive:
+            jssource_recursive(path, file_exclusion)
         # otherwise it's a "normal" iteration and runs the
         # jssource normalization process in it
-        else: jssource_file(path)
+        else:
+            jssource_file(path)
 
     # verifies if there were messages printed to the standard
     # error output and if that's the case exits in error
     sys.exit(1 if extra.has_errors() else 0)
 
+
 if __name__ == "__main__":
     main()
 else:
